<?php
// $Id: logotool.admin.inc,v 1.4 2010/02/11 22:24:58 pobster Exp $

/**
 * @file
 * Logotool admin settings file.
 */

/**
 * Menu callback: Settings.
 */
function logotool_settings() {
  $logo_dir = file_create_path(variable_get('logotool_folder', LOGOTOOL_CWD));
  file_check_directory($logo_dir, 1, 'logotool_folder');
  $form['general']['logotool_path'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to default/ main logo'),
    '#description' => t('The path to the file you would like to use as your default/ main logo (WITH leading slash).'),
    '#default_value' => variable_get('logotool_path', 'misc/druplicon.png'),
  );
  $form['general']['logotool_folder'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to your logos folder'),
    '#description' => t('The path to the folder which contains your logos (NO leading or trailing slashes).'),
    '#default_value' => variable_get('logotool_folder', LOGOTOOL_CWD),
  );
  $form['general']['logotool_display'] = array(
    '#type' => 'select',
    '#title' => t('Display mode'),
    '#description' => t('<p><strong>Normal mode</strong>: Displays the default/ main logo on every page.</p>
      <p><strong>Random logos</strong>: Displays a random logo on every page refresh.</p>
      <p><strong>Specified logos</strong>: Displays a specific logo on each specified page from the
      information below, pages not specified will display the default/ main logo.</p>
      <p><strong>Specified AND Random logos</strong>: Displays a specific logo on each specified page from the
      information below, pages not specified will display a random logo.</p>'),
    '#options' => array(LOGOTOOL_NORMAL => t('Normal mode'), LOGOTOOL_RANDOM => t('Random logos'), LOGOTOOL_SPECIFY => t('Specified logos'), LOGOTOOL_SPECIFY_RANDOM => t('Specified AND Random logos')),
    '#default_value' => variable_get('logotool_display', LOGOTOOL_NORMAL),
  );
  $form['general']['logotool_frequency'] = array(
    '#type' => 'select',
    '#title' => t('Random Frequency'),
    '#description' => t("Select how often your logo is rotated (if you've set it to be random)."),
    '#options' => array(0 => t('Every page refresh'), 60 => t('Every minute'), 3600 => t('Every hour'), 86400 => t('Daily')),
    '#default_value' => variable_get('logotool_frequency', 0),
  );

  $form['settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Logo Page/ Upload Settings'),
    '#collapsed' => TRUE,
    '#collapsible' => TRUE,
  );
  if (module_exists('imagecache')) {
    $form['settings']['logotool_imagecache_preset'] = array(
      '#type' => 'select',
      '#title' => t('Imagecache Preset'),
      '#description' => t('If desired, select an imagecache preset for use with the <a href="!logo-tab-link">logos</a> tab. Using one may make your display more manageable depending on the size of your logos.', array('!logo-tab-link' => url('admin/settings/logotool/logos'))),
      '#options' => _logotool_imagecache_presets(),
      '#default_value' => variable_get('logotool_imagecache_preset', ''),
    );
  }
  $form['settings']['logotool_extensions'] = array(
    '#type' => 'textfield',
    '#title' => t('Allowed upload extensions'),
    '#description' => t('Extensions that can be upload. Separate extensions with a space and do not include the leading dot.'),
    '#default_value' => variable_get('logotool_extensions', 'jpg jpeg gif png'),
  );
  $form['settings']['logotool_max_resolution'] = array('#type' => 'textfield',
    '#title' => t('Maximum resolution for uploaded images'),
    '#default_value' => variable_get('logotool_max_resolution', 0),
    '#size' => 15,
    '#maxlength' => 10,
    '#description' => t('The maximum allowed image size (e.g. 640x480). Set to 0 for no restriction. If an <a href="!image-toolkit-link">image toolkit</a> is installed, files exceeding this value will be scaled down to fit.', array('!image-toolkit-link' => url('admin/settings/image-toolkit'))),
    '#field_suffix' => '<kbd>'. t('WIDTHxHEIGHT') .'</kbd>',
  );
  $form['settings']['logotool_upload_size'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum file size per upload'),
    '#description' => t('The maximum file size that can be upload. If an image is uploaded and a maximum resolution is set, the size will be checked after the file has been resized.'),
    '#default_value' => variable_get('logotool_upload_size', 1),
    '#field_suffix' => t('MB'),
  );
  $form['settings']['upload_max_size'] = array('#value' => '<p>'. t('Your PHP settings limit the maximum file size per upload to %size.', array('%size' => format_size(file_upload_max_size()))) .'</p>');

  return system_settings_form($form);
} // logotool_settings